@@ -296,7 +296,7 @@ def configure_supervisor():
 
     template_vars = {
         'cmd': silk.lib.get_gunicorn_cmd(env, bin_dir='%s/bin' % (env.envdir)),
-        'process_env': _format_supervisord_env(env.config['env']),
+        'process_env': _format_supervisord_env(env.config.get('env', '')),
         'srv_root': SRV_ROOT,
     }
 
